# Changelog

## [1.1.0] (2025-10-19)

 - Add support for Python 3.14
 - Drop support for Python 3.9
 - Drop the "beta" classifier
 - Update the CI

## [1.0.0] (2024-10-13)

 - Adjust to changes how aiohttp handles the SSL parameter
 - Update documentation

## [0.1.16] (2024-10-13)

 - Drop support for Python 3.8
 - Add support for Python 3.13
